pub struct JetStreamTemplate<'a> {
pub body: &'a str,
pub version: &'static str,
pub year: u16,
}Fields
body: &'a strversion: &'static stryear: u16Trait Implementations
Sourceimpl Default for JetStreamTemplate<'_>
impl Default for JetStreamTemplate<'_>
Sourceimpl<'a> Display for JetStreamTemplate<'a>
Implement the format!() trait for JetStreamTemplate
impl<'a> Display for JetStreamTemplate<'a>
Implement the format!() trait for JetStreamTemplate
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl<'a> FastWritable for JetStreamTemplate<'a>
impl<'a> FastWritable for JetStreamTemplate<'a>
Sourcefn write_into<AskamaW>(
&self,
dest: &mut AskamaW,
values: &dyn Values,
) -> Result<()>
fn write_into<AskamaW>( &self, dest: &mut AskamaW, values: &dyn Values, ) -> Result<()>
Used internally by askama to speed up writing some types.
Sourceimpl<'a> Template for JetStreamTemplate<'a>
impl<'a> Template for JetStreamTemplate<'a>
Sourceconst SIZE_HINT: usize = 62597usize
const SIZE_HINT: usize = 62597usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values<AskamaW>(
&self,
__askama_writer: &mut AskamaW,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values<AskamaW>( &self, __askama_writer: &mut AskamaW, __askama_values: &dyn Values, ) -> Result<()>
Renders the template to the given
writer fmt buffer with provided Values.Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it.Sourcefn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
Helper method which allocates a new
String and renders into it with provided Values.Sourcefn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
fn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
Renders the template to the given
writer fmt buffer.Auto Trait Implementations
impl<'a> Freeze for JetStreamTemplate<'a>
impl<'a> RefUnwindSafe for JetStreamTemplate<'a>
impl<'a> Send for JetStreamTemplate<'a>
impl<'a> Sync for JetStreamTemplate<'a>
impl<'a> Unpin for JetStreamTemplate<'a>
impl<'a> UnsafeUnpin for JetStreamTemplate<'a>
impl<'a> UnwindSafe for JetStreamTemplate<'a>